utils

package
v0.0.0-...-b156002 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 13, 2023 License: GPL-3.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Decode

func Decode[T any](encodedData []byte) (T, error)

decode takes a byte slice and decodes it into the specified Go value type

func Encode

func Encode[T any](value T) ([]byte, error)

encode takes any Go value and encodes it to a byte slice

func IsDot

func IsDot(arg string) bool

func RemoveFirstRune

func RemoveFirstRune(s string) string

Types

This section is empty.

Jump to